package de.hft.geotracker

import android.Manifest.permission.ACCESS_FINE_LOCATION
import android.annotation.SuppressLint
import android.content.Intent
import android.content.pm.PackageManager
import android.location.Location
import androidx.appcompat.app.AppCompatActivity
import android.os.Bundle
import android.os.Looper
import android.view.Menu
import android.view.MenuInflater
import android.view.MenuItem
import android.view.Window
import android.widget.ArrayAdapter
import android.widget.AutoCompleteTextView
import android.widget.Spinner
import android.widget.TextView
import androidx.core.app.ActivityCompat
import androidx.core.app.ActivityCompat.requestPermissions
import androidx.navigation.findNavController
import androidx.databinding.DataBindingUtil
import androidx.navigation.ui.NavigationUI
import com.google.android.gms.location.*
import com.google.android.material.textfield.TextInputLayout
import java.util.jar.Manifest


class MainActivity : AppCompatActivity() {
    lateinit var fusedLocationClient : FusedLocationProviderClient
    lateinit var locationRequest : LocationRequest
    lateinit var locationCallback: LocationCallback
    lateinit var actionButton : TextView
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

        setSupportActionBar(findViewById(R.id.my_toolbar))
        setContentView(R.layout.activity_home)

        //        val builder = LocationSettingsRequest.Builder().addLocationRequest(locationRequest)
        createLocationRequest()
        fusedLocationClient = LocationServices.getFusedLocationProviderClient(this)
        if (ActivityCompat.checkSelfPermission(this, ACCESS_FINE_LOCATION) !=
                PackageManager.PERMISSION_GRANTED) {
            requestPermissions(this, arrayOf(ACCESS_FINE_LOCATION), 1000)
        }
        locationCallback = object : LocationCallback() {
            override fun onLocationResult(locationResult: LocationResult?) {
                locationResult ?: return
                for (location in locationResult.locations){
                    // Update UI with location data
                    findViewById<TextView>(R.id.latitude).text = location.latitude.toString()
                    findViewById<TextView>(R.id.longitude).text = location.longitude.toString()
                    findViewById<TextView>(R.id.altitude).text = location.altitude.toString()
                }
            }
        }
//        val binding = DataBindingUtil.setContentView(this, R.layout.activity_main)
//        val navController = this.findNavController(R.id.HostFragment)
//        NavigationUI.setupActionBarWithNavController(this, navController)

//        val dropdown : TextInputLayout = findViewById(R.id.filled_exposed_dropdown)
        /*val editTextFilledExposedDropdown : AutoCompleteTextView = findViewById(R.id.filled_exposed_dropdown)
        ArrayAdapter.createFromResource(this, R.array.accounts, R.layout.spinner_layout).also {
            arrayAdapter -> arrayAdapter.setDropDownViewResource(R.layout.spinner_layout)
            editTextFilledExposedDropdown.setAdapter(arrayAdapter)
        }*/

        /*val array = arrayOf("Test1", "Test2")
        val a : ArrayAdapter<String> = ArrayAdapter(this, R.layout.spinner_layout, array)
        val editTextFilledExposedDropdown : AutoCompleteTextView = findViewById(R.id.filled_exposed_dropdown)
        editTextFilledExposedDropdown.setAdapter(a)*/

        val spinner: Spinner = findViewById(R.id.account_spinner)
        // Create an ArrayAdapter using the string array and a default spinner layout
        ArrayAdapter.createFromResource(this, R.array.accounts, android.R.layout.simple_spinner_item).also { adapter ->
            // Specify the layout to use when the list of choices appears
            adapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item)
            // Apply the adapter to the spinner
            spinner.adapter = adapter
        }
        actionButton = findViewById(R.id.button_start_stop)
        actionButton.setOnClickListener {
            callStartStop()
        }
    }

    private fun callStartStop() {
        println("StartStop pressed")
        fusedLocationClient.lastLocation
            .addOnSuccessListener { location : Location? ->
                if (location != null) {
                    var label = findViewById<TextView>(R.id.display_acc)
                    label.text = location.latitude.toString()

                } else {
                    println("Location = null")
                }
            }
    }

    override fun onResume() {
        super.onResume()
        startLocationUpdates()
    }

    private fun startLocationUpdates() {
        fusedLocationClient.requestLocationUpdates(locationRequest,
            locationCallback,
            Looper.getMainLooper())
    }
    fun createLocationRequest() {
        locationRequest = LocationRequest.create().apply {
            interval = 10000
            fastestInterval = 5000
            priority = LocationRequest.PRIORITY_HIGH_ACCURACY
        }
    }
    override fun onOptionsItemSelected(item: MenuItem) = when (item.itemId) {
        R.id.settings -> {
            // User chose the "Settings" item, show the app settings UI...
            var intent = Intent(this, Settings::class.java)
            startActivity(intent)
            println("test")
            true
        }
        R.id.logout -> {
            // User chose the "Settings" item, show the app settings UI...
            var intent = Intent(this, Login::class.java)
            startActivity(intent)
            true
        }
        else -> {
            // If we got here, the user's action was not recognized.
            // Invoke the superclass to handle it.
            println("test")
            super.onOptionsItemSelected(item)
        }
    }

    override fun onBackPressed() {
    }

}
